#!/bin/sh
# Copyright 1998-2008 VMware, Inc.  All rights reserved.
#
# Configures file paths in GTK+ library.
#

set -e

# BEGINNING_OF_DB_DOT_SH
# END_OF_DB_DOT_SH

# function that does what readlink -f does, but portable:
readlinkf() {
  file=$1

  cd $(dirname $file)
  file=$(basename $file)

  # Iterate down a (possible) chain of symlinks
  while [ -L "$file" ] ; do
    file=$(readlink $file)
    cd $(dirname $file)
    file=$(basename $file)
  done

  realdir=$(pwd -P)
  echo $realdir/$file
}

vmware_db='/etc/vmware-tools/locations'
db_load 'vm_db' "$vmware_db"

confs="$vm_db_answer_LIBDIR/libconf"
pangorc="$confs/etc/pango/pangorc"
pangoModules="$confs/etc/pango/pango.modules"
pangoxAliases="$confs/etc/pango/pangox.aliases"
gdkPixbufLoaders="$confs/etc/gtk-2.0/gdk-pixbuf.loaders"
gtkIMModules="$confs/etc/gtk-2.0/gtk.immodules"
template="@@LIBCONF_DIR@@"

TDIR=/tmp
if [ -n "$TMPDIR" -a -d "$TMPDIR" ]; then
   TDIR=$TMPDIR
fi
tmp_dir=$(mktemp -d $TDIR/tmp_sed.XXXXXX)

for i in pangorc pangoModules pangoxAliases gdkPixbufLoaders gtkIMModules; do
  eval "path=\$$i"
  tmp_file="$tmp_dir/$(basename $path)"
  sed -e "s,$template,$confs,g" < "$path" > "$tmp_file"
  cp "$tmp_file" "$path"; rm "$tmp_file"
  realpath=$(readlinkf $path)
  db_remove_file "$vmware_db" "$realpath"
  db_add_file "$vmware_db" "$realpath" "$realpath"
done

rm -rf $tmp_dir
exit 0
